| Title: | Partially Balanced Incomplete Block Designs |
|---|---|
| Description: | The PBIB designs are important type of incomplete block designs having wide area of their applications for example in agricultural experiments, in plant breeding, in sample surveys etc. This package constructs various series of PBIB designs and assists in checking all the necessary conditions of PBIB designs and the association scheme on which these designs are based on. It also assists in calculating the efficiencies of PBIB designs with any number of associate classes. The package also constructs Youden-m square designs which are Row-Column designs for the two-way elimination of heterogeneity. The incomplete columns of these Youden-m square designs constitute PBIB designs. With the present functionality, the package will be of immense importance for the researchers as it will help them to construct PBIB designs, to check if their PBIB designs and association scheme satisfy various necessary conditions for the existence, to calculate the efficiencies of PBIB designs based on any association scheme and to construct Youden-m square designs for the two-way elimination of heterogeneity. R. C. Bose and K. R. Nair (1939) <http://www.jstor.org/stable/40383923>. |
| Authors: | Parneet Kaur [aut], Kush Sharma [aut, cre], Davinder Kumar Garg [aut] |
| Maintainer: | Kush Sharma <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.4 |
| Built: | 2026-05-13 05:27:22 UTC |
| Source: | https://github.com/cran/PBIBD |
The PBIB designs are important type of incomplete block designs having wide area of their applications for example in agricultural experiments, in plant breeding, in sample surveys etc. This package constructs various series of PBIB designs and assists in checking all the necessary conditions of PBIB designs and the association scheme on which these designs are based on. It also assists in calculating the efficiencies of PBIB designs with any number of associate classes. The package also constructs Youden-m square designs which are Row-Column designs for the two-way elimination of heterogeneity. The incomplete columns of these Youden-m square designs constitute PBIB designs. With the present functionality, the package will be of immense importance for the researchers as it will help them to construct PBIB designs, to check if their PBIB designs and association scheme satisfy various necessary conditions for the existence, to calculate the efficiencies of PBIB designs based on any association scheme and to construct Youden-m square designs for the two-way elimination of heterogeneity.
The DESCRIPTION file:
| Package: | PBIBD |
| Title: | Partially Balanced Incomplete Block Designs |
| Version: | 1.4 |
| Authors@R: | c( person(given = "Parneet", family = "Kaur", role = "aut", email = "[email protected]"), person(given = "Kush", family = "Sharma", role = c("aut", "cre"), email = "[email protected]"), person(given = c("Davinder", "Kumar"), family = "Garg", role = "aut", email = "[email protected]") ) |
| Description: | The PBIB designs are important type of incomplete block designs having wide area of their applications for example in agricultural experiments, in plant breeding, in sample surveys etc. This package constructs various series of PBIB designs and assists in checking all the necessary conditions of PBIB designs and the association scheme on which these designs are based on. It also assists in calculating the efficiencies of PBIB designs with any number of associate classes. The package also constructs Youden-m square designs which are Row-Column designs for the two-way elimination of heterogeneity. The incomplete columns of these Youden-m square designs constitute PBIB designs. With the present functionality, the package will be of immense importance for the researchers as it will help them to construct PBIB designs, to check if their PBIB designs and association scheme satisfy various necessary conditions for the existence, to calculate the efficiencies of PBIB designs based on any association scheme and to construct Youden-m square designs for the two-way elimination of heterogeneity. R. C. Bose and K. R. Nair (1939) <http://www.jstor.org/stable/40383923>. |
| License: | GPL (>= 2) |
| Encoding: | UTF-8 |
| RoxygenNote: | 7.3.2 |
| NeedsCompilation: | no |
| Packaged: | 2025-05-18 18:47:46 UTC; ABC |
| Author: | Parneet Kaur [aut], Kush Sharma [aut, cre], Davinder Kumar Garg [aut] |
| Maintainer: | Kush Sharma <[email protected]> |
| Repository: | https://sharmakush.r-universe.dev |
| Date/Publication: | 2025-05-18 19:28:29 UTC |
| RemoteUrl: | https://github.com/cran/PBIBD |
| RemoteRef: | HEAD |
| RemoteSha: | 71b17d42fd5c881fd5c6f132f1c37d523dfecf37 |
Index of help topics:
apbibd Calculates the efficiencies of PBIB designs
with any number of associate classes.
circulant This function generates circulant matrix of
order n.
PBIBD-package Partially Balanced Incomplete Block Designs
series1 This function constructs five-associate class
PBIB designs.
series2 This function constructs five-associate class
PBIB designs
series3 This function constructs five-associate class
PBIB designs
series4 This function constructs three-associate class
PBIB designs.
series5 This function constructs three-associate class
PBIB designs.
series6 This function constructs three-associate class
PBIB designs.
verify Verifies all the necessary conditions for the
existence of PBIB designs based on any
association scheme.
ym1 Constructs Youden-m square designs and provides
parameters of the corresponding PBIB design
ym2 Constructs Youden-m square designs and provides
the parameters of the corresponding PBIB design
ym3 Constructs Youden-m square designs and provides
parameters of the corresponding PBIB design
This package is currently under intensive development and changes are to be expected in the near future.
Parneet Kaur <[email protected]>
Kush Sharma <[email protected]>
Davinder Kumar Garg <[email protected]>
Maintainer: Kush Sharma <[email protected]>
Dey, A. (1986). Theory of block designs.Wiley Eastern Limited, New Delhi
Garg, D.K., and Singh, G.P. (2015). General solution of normal equations in the intra-block analysis of PBIB designs with any (m>=2) number of associate classes. American Journal of Sustainable Cities and Society, 4(11), 196-202
Kaur, P. and Garg, D. K. (2016). Construction of some higher associate class PBIB designs using symmetrically repeated differences, Arya Bhatta Journal of Mathematics and Informatics, 8(2), 65-78.
Rao, C. R. (1947b). General methods of analysis for incomplete block designs, J. Amer. Statist. Assoc. 42, 541-561
Sharma, K. and Garg, D. K. (2017) Construction of Three associate PBIB designs using some sets of initial blocks. International Journal of Agricultural and Statistical Sciences (IJASS), 13(1): 55-60
Sharma, K. and Garg, D. K. (2017). m-associate PBIB designs using Youden-m Squares. Communications in Statistics-Theory and Methods, In press. DOI: 10.1080/03610926.2017.1324990
This function calculates the different kinds of efficiencies and the overall efficiency factor of Partially Balanced Incomplete Block Designs with any number of associate classes. The total number of treatments i.e. v, replications i.e. r, block size i.e. k, vector l of lambda's (lambda i being the ith element of vector l), vector n of number of associates (n i, i.e. number of ith associates, being the ith element of vector n), a list P of P-matrices of the association scheme of the design (Pi being the ith matrix of the list P) are to be supplied as input to the function.
apbibd(v, r, k, l, n, P)apbibd(v, r, k, l, n, P)
v |
Total number of treatments of the design |
r |
Replication of the treatments in the design |
k |
Block size of the design |
l |
A vector containing lambda 1, lambda 2, lambda 3,..., lambda m as its first, second, third,..., mth elements |
n |
A vector containing n1, n 2, n 3, ..., n m as its first, second, third,..., mth elements |
P |
A list containing P-matrices of the association scheme of the design such that P1 is its first element, P2 is second element, P3 is third element,..., Pm is the mth element |
Returns a list with (m+1) components:
E1 |
Efficiency E1 of the design |
E2 |
Efficiency E2 of the design and so on ... |
Em |
Efficiency Em of the design |
E |
Overall efficiency factor of the design |
Kush Sharma, Davinder Kumar Garg
v<-25 r<-9 k<-9 l<-c(5,2,5,2,5) n<-c(2,8,2,8,4) P1<-matrix(c(0,0,1,0,0,0,0,0,4,4,1,0,1,0,0,0,4,0,4,0,0,4,0,0,0),nrow=5,ncol=5) P2<-matrix(c(0,0,0,1,1,0,0,1,3,3,0,1,0,1,0,1,3,1,3,0,1,3,0,0,0),nrow=5,ncol=5) P3<-matrix(c(1,0,1,0,0,0,4,0,4,0,1,0,0,0,0,0,4,0,0,4,0,0,0,4,0),nrow=5,ncol=5) P4<-matrix(c(0,1,0,1,0,1,3,1,3,0,0,1,0,0,1,1,3,0,0,3,0,0,1,3,0),nrow=5,ncol=5) P5<-matrix(c(0,2,0,0,0,2,6,0,0,0,0,0,0,2,0,0,0,2,6,0,0,0,0,0,3),nrow=5,ncol=5) P<-list(P1,P2,P3,P4,P5) apbibd(v,r,k,l,n,P)v<-25 r<-9 k<-9 l<-c(5,2,5,2,5) n<-c(2,8,2,8,4) P1<-matrix(c(0,0,1,0,0,0,0,0,4,4,1,0,1,0,0,0,4,0,4,0,0,4,0,0,0),nrow=5,ncol=5) P2<-matrix(c(0,0,0,1,1,0,0,1,3,3,0,1,0,1,0,1,3,1,3,0,1,3,0,0,0),nrow=5,ncol=5) P3<-matrix(c(1,0,1,0,0,0,4,0,4,0,1,0,0,0,0,0,4,0,0,4,0,0,0,4,0),nrow=5,ncol=5) P4<-matrix(c(0,1,0,1,0,1,3,1,3,0,0,1,0,0,1,1,3,0,0,3,0,0,1,3,0),nrow=5,ncol=5) P5<-matrix(c(0,2,0,0,0,2,6,0,0,0,0,0,0,2,0,0,0,2,6,0,0,0,0,0,3),nrow=5,ncol=5) P<-list(P1,P2,P3,P4,P5) apbibd(v,r,k,l,n,P)
Circulant matrix, which is a special kind of Toeplitz matrix, is a square matrix of order n whose rows are obtained by cyclically rotated versions of a list “l” of length n such that the first row is obtained by cyclically rotating one element toward right the list “l” and each of the other row is the cyclically rotated one element toward the right version of the previous row. This function is used to generate a circulant matrix of order n. The order of the circulant matrix i.e. n is supplied as an argument to the function.
circulant(n)circulant(n)
n |
n is the order of the circulant matrix we want to generate. |
The function returns a circulant matrix c of order n.
Kush Sharma, Davinder Kumar Garg
circulant(7)circulant(7)
Let us consider a module M of residue class mod(5) having elements 0, 1, 2, 3, 4 and all the elements of M are assigned to each of the n >= 2 classes. This function constructs PBIB designs with the following parameters:
v = 5n, b = 5n, r = n+4, k = n+4
lambda 1 = 5, lambda 2 = 2, lambda 3 = 5, lambda 4 = 2, lambda 5 = n
series1(n)series1(n)
n |
n is the number of classes to which the elements of Module M are assigned |
The function returns the required PBIB design with specified parameters
Parneet Kaur, Davinder Kumar Garg
series1(2)series1(2)
Let us consider a module M of residue class mod(5) having elements 0, 1, 2, 3, 4 and all the elements of M are assigned to each of the n >= 2 classes. This function constructs PBIB designs with the following parameters:
v = 5n, b = 5n, r = n+3, k = n+3
lambda 1 = 3, lambda 2 = 1, lambda 3 = 3, lambda 4 = 2, lambda 5 = n
series2(n)series2(n)
n |
n is the number of classes to which the elements of Module M are assigned. |
The function returns the required PBIB design with specified parameters.
Parneet Kaur, Davinder Kumar Garg
series2(4)series2(4)
Let us consider a module M of residue class mod(5) having elements 0, 1, 2, 3, 4 and all the elements of M are assigned to each of the n >= 2 classes. This function constructs PBIB designs with the following parameters:
v = 5n, b = 5n, r = 2(n + 1), k = 2(n + 1)
lambda 1 = n + 2, lambda 2 = n + 2, lambda 3 = 3, lambda 4 = 2, lambda 5 = 2n
series3(n)series3(n)
n |
n is the number of classes to which the elements of Module M are assigned |
The function returns the required PBIB design with specified parameters
Parneet Kaur, Davinder Kumar Garg
series3(5)series3(5)
Let us consider a module M having m elements. To each element of the module, there corresponds n distinct classes, where m >= 5 and n >= 2. With these v = mn treatments following are parameters of the three-associate class PBIB design:
v = mn, b = mn, r = (m+n-1), k = (m+n-1)
lambda 1 = m, lambda 2 = 2, lambda 3 = n
series4(m, n)series4(m, n)
m |
Size of the module M. |
n |
n is the number of classes to which the elements of Module M are assigned. |
This function returns the required three-associate class PBIB design.
Parneet Kaur, Davinder Kumar Garg
series4(5,2)series4(5,2)
Consider a module M having m elements and there are n classes corresponding to each element of the module. Thus, we have a total of v = mn treatments (m is odd prime). For these v = mn treatments following are the parameters of the three-associate class PBIB design:
v = mn, b = mn, r = (m+n-2), k = (m+n-2)
lambda 1 = m-2, lambda 2 = 2, lambda 3 = n-2
series5(m, n)series5(m, n)
m |
Size of Module M. |
n |
n is the number of classes to which the elements of Module M are assigned. |
The function returns the required three-associate class PBIB design with the parameters specified in the description.
Kush Sharma, Davinder Kumar Garg
series5(5,3)series5(5,3)
Consider a module M having m elements and there are n classes corresponding to each element of the module. Thus, we have a total of v = mn treatments (m is odd prime). For these v = mn treatments following are the parameters of the three-associate class PBIB design:
v = mn, b = m, r = (m-1), k = (m-1)n
lambda 1 = m-2, lambda 2 = m-2, lambda 3 = m-1
series6(m, n)series6(m, n)
m |
Size of Module M. |
n |
n is the number of classes to which the elements of Module M are assigned. |
The function returns the required three-associate class PBIB design with the parameters specified in the description.
Kush Sharma, Davinder Kumar Garg
series6(5,3)series6(5,3)
There exists various necessary conditions for the existence of the PBIB design as well as the association scheme on which the PBIB design is based. This function Verifies all those necessary conditions for the existence of PBIB designs based on any association scheme. The total number of treatments i.e. v, the total number of blocks i.e. b, replications i.e. r, block size i.e. k, vector l of lambda's (lambda i being the ith element of vector l), vector n of number of associates (n i, i.e. number of ith associates, being the ith element of vector n), a list P of P-matrices of the association scheme of the design (Pi being the ith matrix of the list P) are to be supplied as input to the function.
verify(v, b, r, k, l, n, P)verify(v, b, r, k, l, n, P)
v |
Total number of treatments of the design |
b |
Total number of blocks in the design |
r |
Replication of the treatments in the design |
k |
Block size of the design |
l |
A vector containing lambda 1, lambda 2, lambda 3,..., lambda m as its first, second, third,..., mth elements |
n |
A vector containing n 1, n 2, n 3, ..., n m as its first, second, third,..., mth elements |
P |
A list containing P-matrices of the association scheme of the design such that P1 is its first element, P2 is second element, P3 is third element,..., Pm is the mth element |
The function tells if all the necesary conditions for the existence of PBIB design based on some association scheme hold. If not, it highlights all the conditions which do not hold.
Kush Sharma, Davinder Kumar Garg
v<-12 b<-12 r<-5 k<-5 l<-c(1,2,2) n<-c(2,3,6) P1<-matrix(c(1,0,0,0,0,3,0,3,3),nrow=3,ncol=3) P2<-matrix(c(0,0,2,0,2,0,2,0,4),nrow=3,ncol=3) P3<-matrix(c(0,1,1,1,0,2,1,2,2),nrow=3,ncol=3) P<-list(P1,P2,P3) verify(v,b,r,k,l,n,P)v<-12 b<-12 r<-5 k<-5 l<-c(1,2,2) n<-c(2,3,6) P1<-matrix(c(1,0,0,0,0,3,0,3,3),nrow=3,ncol=3) P2<-matrix(c(0,0,2,0,2,0,2,0,4),nrow=3,ncol=3) P3<-matrix(c(0,1,1,1,0,2,1,2,2),nrow=3,ncol=3) P<-list(P1,P2,P3) verify(v,b,r,k,l,n,P)
If the same number of rows, say , are omitted from the top and bottom of a Circulant matrix such that at least two rows remain, the resulting arrangement forms a Youden-m square.
(A) For even-ordered Circulant matrices (order and even), the columns of the resulting Youden-m square constitute a PBIB design with parameters:
,
, for
If , then for
(B) For odd-ordered Circulant matrices (order and odd), the columns of the resulting Youden-m square constitute a PBIB design with parameters:
,
, for
, for
ym1(n, t)ym1(n, t)
n |
Order of the circulant matrix, which is also the number of treatments. |
t |
Number of rows to omit from both the top and bottom of the circulant matrix. |
The function returns the Youden-m square design and the parameters of the PBIB design formed by taking its incomplete columns as blocks.
Kush Sharma, Davinder Kumar Garg
ym1(6, 1)ym1(6, 1)
By omitting the middle rows (where ) from any even-ordered Circulant matrix with order , and considering only those rows that lie either above or below the omitted rows, the resulting arrangement gives a new type of Youden-m square.
The columns of these Youden-m squares constitute -associate class PBIB designs, with the following parameters:
and even, ,
,
If is even, then:
for
for
If is odd, then:
for
for
ym2(n, t)ym2(n, t)
n |
|
t |
|
The function returns the required Youden-m square design and the parameters of the PBIB design constituted by taking the incomplete columns of the Youden-m square as blocks.
Kush Sharma, Davinder Kumar Garg
ym2(8, 1)ym2(8, 1)
This function constructs a Youden-m square by omitting the middle row and an equal number of rows from both ends of an odd-ordered Circulant matrix of order . The rows retained lie between the middle omitted row and the omitted rows from the top or bottom. This arrangement yields a Youden-m square suitable for two-way elimination of heterogeneity.
The columns of this Youden-m square constitute a PBIB design with the following parameters:
and odd
,
for
If , then for
ym3(n, t)ym3(n, t)
n |
Order of the circulant matrix, which is also the number of treatments. |
t |
Number of rows to omit from both ends of the circulant matrix. |
The function returns the constructed Youden-m square design and the parameters of the PBIB design obtained by treating the incomplete columns of the square as blocks.
Kush Sharma, Davinder Kumar Garg
ym3(7, 1)ym3(7, 1)